//[mahjong-utils](../../index.md)/[mahjongutils.shanten](index.md)/[asWithGot](as-with-got.md)

# asWithGot

[common]\
val [CommonShanten](-common-shanten/index.md).[asWithGot](as-with-got.md): [ShantenWithGot](-shanten-with-got/index.md)
